package com.hcloud.microservice.org.facade.client;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.org.facade.fallback.factory.RoleManagerFallbackFactory;
import com.hcloud.microservice.org.facade.forms.BaseRoleAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseRoleForm;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @author xiezt
 */
@FeignClient(value = "org-service",path = "/role",fallbackFactory = RoleManagerFallbackFactory.class)
public interface RoleManagerService {

    /**
     * 分页查询角色信息
     * @param baseRoleForm
     * @return
     */
    @PostMapping("/searchByPage")
    ResultVO searchRoleInfoByPage(@RequestBody BaseRoleForm baseRoleForm);

    /**
     * 添加角色信息
     * @param baseRoleForm
     * @return
     */
    @PostMapping("/addRoleInfo")
    ResultVO addRoleInfo(@RequestBody BaseRoleForm baseRoleForm);

    /**
     * 更新角色信息
     * @param baseRoleForm
     * @return
     */
    @PostMapping("/updateRoleInfo")
    ResultVO updateRoleInfo(@RequestBody BaseRoleForm baseRoleForm);


    /**
     * 查询角色明细信息
     * @param guid
     * @return
     */
    @PostMapping("/searchById")
    ResultVO searchInfoById(@RequestParam("guid") String guid);

    /**
     * 查询已分配角色权限信息
     * @param roleId
     * @param orgGuid
     * @return
     */
    @PostMapping("/searchRoleAuthInfo")
    ResultVO searchRoleAuthInfo(@RequestParam("roleId") String roleId, @RequestParam("orgGuid") String orgGuid);

    /**
     * 分配角色权限
     * @param roleId
     * @param orgGuid
     * @param list
     * @return
     */
    @PostMapping("/distribedRoleAuth")
    ResultVO distributionRoleAuth(@RequestParam("roleId") String roleId,@RequestParam("orgGuid") String orgGuid,@RequestBody List<BaseRoleAuthForm> list);
}
