package com.hcloud.microservice.org.facade.client;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microservice.org.facade.fallback.factory.UserManagerFallbackFactory;
import com.hcloud.microservice.org.facade.forms.BaseUserAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseUserForm;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @author xiezt
 */
@FeignClient(value = "org-service",path = "/user",fallbackFactory = UserManagerFallbackFactory.class)
public interface UserManagerService {

    /**
     * 分页查询用户信息
     * @param baseUserForm
     * @return
     */
    @PostMapping("/searchByPage")
    ResultVO searchUserInfoByPage(@RequestBody BaseUserForm baseUserForm);

    /**
     * 添加用户
     * @param baseUserForm
     * @return
     */
    @PostMapping("/addUserInfo")
    ResultVO addUserInfo(@RequestBody BaseUserForm baseUserForm);

    /**
     * 更新用户信息
     * @param baseUserForm
     * @return
     */
    @PostMapping("/updateUserInfo")
    ResultVO updateUserInfo(@RequestBody BaseUserForm baseUserForm);

    /**
     * 查询用户权限
     * @param userId
     * @param orgGuid
     * @return
     */
    @GetMapping("/searchUserAuthInfo")
    ResultVO searchUserAuthInfo(@RequestParam("userId") String userId, @RequestParam("orgGuid") String orgGuid);

    /**
     * 分配权限
     * @param userId
     * @param orgGuid
     * @param list
     * @return
     */
    @PostMapping("/distribedUserAuthInfo")
    ResultVO distributionUserAuthInfo(@RequestParam("userId") String userId,
                                      @RequestParam("orgGuid") String orgGuid,
                                      @RequestBody List<BaseUserAuthForm> list);

    /**
     * 用户登录系统
     * @param account
     * @param password
     * @return
     */
    @PostMapping("/loginSys")
    ResultVO loginSystem(@RequestParam("account") String account,
                         @RequestParam("password") String password);


    /**
     * 获取用户菜单信息
     * @param userId
     * @param orgGuid
     * @return
     */
    @PostMapping("/getUserMenus")
    ResultVO getUserMenusInfo(@RequestParam("userId") String userId,
                              @RequestParam("orgGuid") String orgGuid);

    /**
     * 获取菜单子功能信息
     * @param baseUserAuthForm
     * @return
     */
    @PostMapping("/getUserSubAuth")
    ResultVO getSubUserAuthInfo(@RequestBody BaseUserAuthForm baseUserAuthForm);
}
