package com.hcloud.microservice.org.facade.fallback.factory;

import com.hcloud.microserver.commoncore.base.ResultVO;
import com.hcloud.microserver.commoncore.enums.ResultEnum;
import com.hcloud.microservice.org.facade.fallback.UserMangerFactory;
import com.hcloud.microservice.org.facade.forms.BaseUserAuthForm;
import com.hcloud.microservice.org.facade.forms.BaseUserForm;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author xiezt
 */
@Slf4j
@Component
public class UserManagerFallbackFactory implements FallbackFactory<UserMangerFactory> {

    @Override
    public UserMangerFactory create(Throwable cause) {
        return new UserMangerFactory() {
            @Override
            public ResultVO searchUserInfoByPage(BaseUserForm baseUserForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            @Override
            public ResultVO addUserInfo(BaseUserForm baseUserForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            @Override
            public ResultVO updateUserInfo(BaseUserForm baseUserForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            @Override
            public ResultVO searchUserAuthInfo(String userId, String orgGuid) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }
            /**
             * 分配用户权限
             *
             * @param userId
             * @param orgGuid
             * @param list
             * @return
             */
            @Override
            public ResultVO distributionUserAuthInfo(String userId, String orgGuid, List<BaseUserAuthForm> list) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 用户登录系统
             *
             * @param account
             * @param password
             * @return
             */
            @Override
            public ResultVO loginSystem(String account, String password) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 获取用户菜单信息
             *
             * @param userId
             * @param orgGuid
             * @return
             */
            @Override
            public ResultVO getUserMenusInfo(String userId, String orgGuid) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }

            /**
             * 获取菜单子功能信息
             *
             * @param baseUserAuthForm
             * @return
             */
            @Override
            public ResultVO getSubUserAuthInfo(BaseUserAuthForm baseUserAuthForm) {
                return new ResultVO<>(ResultEnum.SYS_BREAK_ERROR);
            }
        };
    }
}
